<?php


// No direct calls to this script
if ( strpos($_SERVER['PHP_SELF'], basename(__FILE__) )) {
	die('No direct calls allowed!');
}


/*
 * Widget to display the next events.
 *
 * @since 1.0.0
 */
if (function_exists('register_sidebar') && class_exists('WP_Widget')) {
	class SSEC_Widget_Calendar extends WP_Widget {

		/* Constructor */
		function __construct() {
			$widget_ops = array(
				'classname' => 'ssec_widget_calendar',
				'description' => esc_html__( 'Super Simple Event Calendar.', 'super-simple-event-calendar'  ),
				'customize_selective_refresh' => true,
			);
			parent::__construct( 'ssec_widget_calendar', esc_html__( 'Event Calendar', 'super-simple-event-calendar'  ), $widget_ops );
			$this->alt_option_name = 'ssec_widget_calendar';
		}

		/** @see WP_Widget::widget */
		function widget($args, $instance) {
			extract($args);

			$default_value = array(
					'title'       => esc_html__('Calendar', 'super-simple-event-calendar'),
					'num_entries' => 3,
				);
			$instance      = wp_parse_args( (array) $instance, $default_value );

			$widget_title  = esc_attr($instance['title']);
			$num_entries   = (int) esc_attr($instance['num_entries']);
			$postid        = (int) esc_attr($instance['postid']);

			// Init
			$widget_html = '';

			$widget_html .= $before_widget;
			$widget_html .= '
				<div class="ssec-widget-calendar">';

			if ($widget_title !== FALSE) {
				$widget_html .= $before_title . apply_filters('widget_title', $widget_title) . $after_title;
			}

			$widget_html .= '
				<ul class="ssec-widget-calendar-list">';

			$args = array(
				'post_type'      => 'ssec_event',
				'post_status'    => 'future',
				'posts_per_page' => $num_entries,
				'orderby'        => 'date',
				'order'          => 'ASC',
			);

			// The Query
			$the_query = new WP_Query( $args );

			// The Loop
			if ( $the_query->have_posts() ) {
				while ( $the_query->have_posts() ) {
					$the_query->the_post();
					$classes = ssec_get_term_classes( get_the_ID() );
					$widget_html .= '
						<li class="ssec-widget-listitem ' . $classes . '">
							<span class="ssec-title">' . get_the_title() . '</span><br />
							<span class="ssec-content">' . nl2br(get_the_content()) . '</span>
						</li>
						';
				}
			} else {
				// no posts found
			}
			/* Restore original Post Data */
			wp_reset_postdata();

			$widget_html .= '
				</ul>';

			// Post the link to the Calendar.
			if ( (int) $postid > 0 ) {
				$permalink = get_permalink( $postid );
				$widget_html .= '
					<p class="ssec-widget-calendar-link">
						<a href="' . $permalink . '" title="' . esc_attr__('View Full Calendar.', 'super-simple-event-calendar') . '">' . esc_html__('Full Calendar', 'super-simple-event-calendar') . ' &raquo;</a>
					</p>';
			}

			$widget_html .= '
			</div>' . $after_widget;

			if ( $the_query->have_posts() ) {
				// Only display widget if there are any entries
				echo $widget_html;
			}
		}

		/** @see WP_Widget::update */
		function update($new_instance, $old_instance) {
			$instance = $old_instance;
			$instance['title']       = strip_tags($new_instance['title']);
			$instance['num_entries'] = (int) strip_tags($new_instance['num_entries']);
			$instance['postid']      = (int) $new_instance['postid'];

			return $instance;
		}

		/** @see WP_Widget::form */
		function form($instance) {

			$default_value = array(
					'title'       => esc_html__('Calendar', 'super-simple-event-calendar'),
					'num_entries' => 3,
					'postid'      => 0
				);
			$instance      = wp_parse_args( (array) $instance, $default_value );

			$title         = esc_attr($instance['title']);
			$num_entries   = (int) esc_attr($instance['num_entries']);
			$postid        = (int) esc_attr($instance['postid']);
			?>

			<p>
				<label for="<?php echo $this->get_field_id('title'); ?>" /><?php esc_html_e('Title:', 'super-simple-event-calendar'); ?></label>
				<br />
				<input type="text" id="<?php echo $this->get_field_id('title'); ?>" value="<?php echo $title; ?>" name="<?php echo $this->get_field_name('title'); ?>" />
			</p>

			<p>
				<label for="<?php echo $this->get_field_id('num_entries'); ?>" /><?php esc_html_e('Number of items:', 'super-simple-event-calendar'); ?></label>
				<br />
				<select id="<?php echo $this->get_field_id('num_entries'); ?>" name="<?php echo $this->get_field_name('num_entries'); ?>">
					<?php
					for ($i = 1; $i <= 15; $i++) {
						echo '<option value="' . $i . '"';
						if ( $i === $num_entries ) {
							echo ' selected="selected"';
						}
						echo '>' . $i . '</option>';
					}
					?>
				</select>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id('postid'); ?>"><?php esc_html_e('Select the page of the calendar:', 'super-simple-event-calendar'); ?></label>
				<br />
				<select id="<?php echo $this->get_field_id('postid'); ?>" name="<?php echo $this->get_field_name('postid'); ?>">
					<option value="0"><?php esc_html_e('Select page', 'super-simple-event-calendar'); ?></option>
					<?php
					$args = array(
						'post_type'              => 'page',
						'orderby'                => 'title',
						'order'                  => 'ASC',
						'posts_per_page'         => 500,
						'update_post_term_cache' => false,
						'update_post_meta_cache' => false
					);

					$sel_query = new WP_Query( $args );
					if ( $sel_query->have_posts() ) {
						while ( $sel_query->have_posts() ) : $sel_query->the_post();
							$selected = false;
							if ( get_the_ID() == $postid ) {
								$selected = true;
							}
							echo '<option value="' . get_the_ID() . '"'
							. selected( $selected )
							. '>'. get_the_title() . '</option>';
						endwhile;
					}
					wp_reset_postdata(); ?>
				</select>
			</p>

			<?php
		}

	}

	function ssec_widget_calendar_init() {
		register_widget('SSEC_Widget_Calendar');
	}
	add_action('widgets_init', 'ssec_widget_calendar_init' );
}

