<?php
/*
Plugin Name: Super Simple Event Calendar
Plugin URI: https://wordpress.org/plugins/super-simple-event-calendar/
Description: Super Simple Event Calendar is an event calendar for people who just want something simple for events.
Version: 1.1.3
Author: Marcel Pol
Author URI: https://timelord.nl
License: GPLv2 or later
Text Domain: super-simple-event-calendar
Domain Path: /lang/
*/

/*
	Copyright 2018 - 2020  Marcel Pol  (email: marcel@timelord.nl)

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/


// Plugin Version
define('SSEC_VER', '1.1.3');


/*
 * Todo List:
 *
 */


/*
 * Definitions
 */
define('SSEC_FOLDER', plugin_basename(dirname(__FILE__)));
define('SSEC_DIR', WP_PLUGIN_DIR . '/' . SSEC_FOLDER);
define('SSEC_URL', plugins_url( '/', __FILE__ ));


include_once( SSEC_DIR . '/ssec-hooks.php' );
include_once( SSEC_DIR . '/ssec-posttypes.php' );
include_once( SSEC_DIR . '/ssec-shortcode.php' );
include_once( SSEC_DIR . '/ssec-taxonomy-content-filter.php' );
include_once( SSEC_DIR . '/ssec-widget-calendar.php' );


/*
 * Get the terms of each event post in the form of classes.
 *
 * @param int $postid instance of WP_Post
 * @return string text with term classes of this event post.
 * @since 1.1.1
 */
function ssec_get_term_classes( $postid ) {
	$postid = (int) $postid;
	$seasons = get_the_terms( $postid, 'ssec_season' );
    $classes = array();

	if ( $seasons && ! is_wp_error( $seasons ) ) {
		$classes[] = 'ssec-season';
		foreach ( $seasons as $season ) {
			if ( isset( $season->term_id ) ) {
				$class = sanitize_html_class( $season->slug, $season->term_id );
				$classes[] = 'ssec-season-' . $class;
				$classes[] = 'ssec-season-' . $season->term_id;
			}
		}
	}
	$classes = join( " ", $classes );
	return $classes;
}
